// 	$Id: BoolNet.m,v 1.3 1999/02/16 02:21:13 alex Exp $	

#define __USE_FIXED_PROTOTYPES__  // for gcc headers

#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#import <booleannet.h>

@implementation BoolNet

-createEnd {

  [super createEnd];  
  return self;

}

// -dropAllLinks {
//   id index, entity, fromList, linkIndex, link;

//   index = [[self getNodeList] begin: globalZone] ;
//   while( (entity = [index next]) ) {  
//     fromList = [entity getInputLinks];
//     // get the run-time type of this object
//     linkIndex = [fromList begin: globalZone] ;
//     while( (link = [linkIndex next]) ) 
//       //      trace("class is of type %s\n", objc_lookUpClass(link));
//       [link drop];         // remove the link
//     [linkIndex drop];
//   }
//   [index drop];
//   return self;
// }

@end
